@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021  The Software Heritage developers
+# Copyright (C) 2015-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -73,9 +73,6 @@ class SchedulerBackend:
             )
             self._db = None
 
-    def get_current_version(self):
-        return self.current_version
-
     def get_db(self):
         if self._db:
             return self._db
@@ -176,6 +173,9 @@ class SchedulerBackend:
               where id in %s
         """
 
+        if not lister_ids:
+            return []
+
         cur.execute(query, (tuple(lister_ids),))
 
         return [Lister(**row) for row in cur]
@@ -314,6 +314,7 @@ class SchedulerBackend:
         self,
         lister_id: Optional[UUID] = None,
         url: Optional[str] = None,
+        enabled: Optional[bool] = True,
         limit: int = 1000,
         page_token: Optional[ListedOriginPageToken] = None,
         db=None,
@@ -334,6 +335,10 @@ class SchedulerBackend:
             query_filters.append("url = %s")
             query_params.append(url)
 
+        if enabled is not None:
+            query_filters.append("enabled = %s")
+            query_params.append(enabled)
+
         if page_token is not None:
             query_filters.append("(lister_id, url) > %s")
             # the typeshed annotation for tuple() is too strict.
@@ -371,7 +376,10 @@ class SchedulerBackend:
         policy: str,
         enabled: bool = True,
         lister_uuid: Optional[str] = None,
+        lister_name: Optional[str] = None,
+        lister_instance_name: Optional[str] = None,
         timestamp: Optional[datetime.datetime] = None,
+        absolute_cooldown: Optional[datetime.timedelta] = datetime.timedelta(hours=12),
         scheduled_cooldown: Optional[datetime.timedelta] = datetime.timedelta(days=7),
         failed_cooldown: Optional[datetime.timedelta] = datetime.timedelta(days=14),
         not_found_cooldown: Optional[datetime.timedelta] = datetime.timedelta(days=31),
@@ -384,6 +392,10 @@ class SchedulerBackend:
 
         origin_select_cols = ", ".join(ListedOrigin.select_columns())
 
+        joins: Dict[str, str] = {
+            "origin_visit_stats": "USING (url, visit_type)",
+        }
+
         query_args: List[Any] = []
 
         where_clauses = []
@@ -398,6 +410,15 @@ class SchedulerBackend:
         where_clauses.append("visit_type = %s")
         query_args.append(visit_type)
 
+        if absolute_cooldown:
+            # Don't schedule visits if they've been scheduled since the absolute cooldown
+            where_clauses.append(
+                """origin_visit_stats.last_scheduled IS NULL
+                   OR origin_visit_stats.last_scheduled < %s
+                """
+            )
+            query_args.append(timestamp - absolute_cooldown)
+
         if scheduled_cooldown:
             # Don't re-schedule visits if they're already scheduled but we haven't
             # recorded a result yet, unless they've been scheduled more than a week
@@ -496,14 +517,27 @@ class SchedulerBackend:
             where_clauses.append("lister_id = %s")
             query_args.append(lister_uuid)
 
+        if lister_name:
+            joins["listers"] = "on listed_origins.lister_id=listers.id"
+            where_clauses.append("listers.name = %s")
+            query_args.append(lister_name)
+
+        if lister_instance_name:
+            joins["listers"] = "on listed_origins.lister_id=listers.id"
+            where_clauses.append("listers.instance_name = %s")
+            query_args.append(lister_instance_name)
+
+        join_clause = "\n".join(
+            f"left join {table} {clause}" for table, clause in joins.items()
+        )
+
         # fmt: off
         common_table_expressions.insert(0, ("selected_origins", f"""
             SELECT
               {origin_select_cols}, next_visit_queue_position
             FROM
               {table}
-            LEFT JOIN
-              origin_visit_stats USING (url, visit_type)
+            {join_clause}
             WHERE
               ({") AND (".join(where_clauses)})
             ORDER BY
