@@ -26,14 +26,14 @@ scheduler:
 """
 
 
-def invoke(scheduler, catch_exceptions, args):
+def invoke(scheduler, catch_exceptions, args, config=CLI_CONFIG):
     runner = CliRunner()
     with patch(
         "swh.scheduler.get_scheduler"
     ) as get_scheduler_mock, tempfile.NamedTemporaryFile(
         "a", suffix=".yml"
     ) as config_fd:
-        config_fd.write(CLI_CONFIG)
+        config_fd.write(config)
         config_fd.seek(0)
         get_scheduler_mock.return_value = scheduler
         args = [
@@ -163,6 +163,20 @@ Task 1
     assert re.fullmatch(expected, result.output, re.MULTILINE), result.output
 
 
+def test_schedule_unknown_task_type(swh_scheduler):
+    """When scheduling unknown task type, the cli should raise."""
+    with pytest.raises(ValueError, match="Unknown"):
+        invoke(
+            swh_scheduler,
+            False,
+            [
+                "task",
+                "add",
+                "unknown-task-type-should-raise",
+            ],
+        )
+
+
 def test_list_pending_tasks_none(swh_scheduler):
     result = invoke(
         swh_scheduler,
