@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -795,15 +795,47 @@ class TestScheduler:
         assert ret.next_page_token is None
         assert len(ret.results) == len(listed_origins)
 
-    def _grab_next_visits_setup(self, swh_scheduler, listed_origins_by_type):
+    def test_get_listed_origins_with_enabled_parameter(
+        self, swh_scheduler, listed_origins_with_non_enabled
+    ) -> None:
+        swh_scheduler.record_listed_origins(listed_origins_with_non_enabled)
+
+        # get all enabled listed origins
+        ret = swh_scheduler.get_listed_origins(
+            enabled=True, limit=len(listed_origins_with_non_enabled) + 1
+        )
+        assert ret.next_page_token is None
+        assert len(ret.results) == len(
+            [lo for lo in listed_origins_with_non_enabled if lo.enabled]
+        )
+        assert all([lo.enabled for lo in ret.results])
+
+        # get all disabled listed origins
+        ret = swh_scheduler.get_listed_origins(
+            enabled=False, limit=len(listed_origins_with_non_enabled) + 1
+        )
+        assert ret.next_page_token is None
+        assert len(ret.results) == len(
+            [lo for lo in listed_origins_with_non_enabled if not lo.enabled]
+        )
+        assert all([not lo.enabled for lo in ret.results])
+
+        # get all listed origins
+        ret = swh_scheduler.get_listed_origins(
+            enabled=None, limit=len(listed_origins_with_non_enabled) + 1
+        )
+        assert ret.next_page_token is None
+        assert len(ret.results) == len(listed_origins_with_non_enabled)
+
+    def _grab_next_visits_setup(self, swh_scheduler, listed_origins_by_type, limit=100):
         """Basic origins setup for scheduling policy tests"""
         visit_type = next(iter(listed_origins_by_type))
-        origins = listed_origins_by_type[visit_type][:100]
+
+        all_origins = listed_origins_by_type[visit_type]
+        origins = all_origins[:limit] if limit else all_origins
         assert len(origins) > 0
 
-        recorded_origins = swh_scheduler.record_listed_origins(origins)
-
-        return visit_type, recorded_origins
+        return visit_type, swh_scheduler.record_listed_origins(origins)
 
     def _check_grab_next_visit_basic(
         self, swh_scheduler, visit_type, policy, expected, **kwargs
@@ -915,7 +947,9 @@ class TestScheduler:
             expected=expected,
         )
 
-    @pytest.mark.parametrize("which_cooldown", ("scheduled", "failed", "not_found"))
+    @pytest.mark.parametrize(
+        "which_cooldown", ("scheduled", "failed", "not_found", "absolute")
+    )
     @pytest.mark.parametrize("cooldown", (7, 15))
     def test_grab_next_visits_cooldowns(
         self,
@@ -934,14 +968,22 @@ class TestScheduler:
             expected=expected,
         )
 
-        # Mark all the visits as scheduled, failed or notfound on the `after` timestamp
+        # Mark all the visits as scheduled, failed or not_found on the `after` timestamp.
+        # If we're testing the `absolute_cooldown`, mark the visit as successful.
         ovs_args = {
             "last_visit": None,
             "last_visit_status": None,
             "last_scheduled": None,
+            "last_successful": None,
+            "last_snapshot": None,
         }
         if which_cooldown == "scheduled":
             ovs_args["last_scheduled"] = after
+        elif which_cooldown == "absolute":
+            ovs_args["last_visit"] = after
+            ovs_args["last_successful"] = after
+            ovs_args["last_visit_status"] = LastVisitStatus.successful
+            ovs_args["last_snapshot"] = b"\x00" * 20
         else:
             ovs_args["last_visit"] = after
             ovs_args["last_visit_status"] = LastVisitStatus(which_cooldown)
@@ -950,8 +992,6 @@ class TestScheduler:
             OriginVisitStats(
                 url=origin.url,
                 visit_type=origin.visit_type,
-                last_snapshot=None,
-                last_successful=None,
                 **ovs_args,
             )
             for i, origin in enumerate(origins)
@@ -963,6 +1003,7 @@ class TestScheduler:
             "scheduled_cooldown": None,
             "failed_cooldown": None,
             "not_found_cooldown": None,
+            "absolute_cooldown": None,
         }
         cooldown_args[f"{which_cooldown}_cooldown"] = cooldown_td
 
@@ -1262,6 +1303,29 @@ class TestScheduler:
             expected=expected_origins,
         )
 
+    def test_grab_next_visit_for_specific_lister(
+        self, swh_scheduler, listed_origins_by_type, stored_lister
+    ):
+        """Checks grab_next_visits filters on the given lister {name, instance name}"""
+
+        visit_type, origins = self._grab_next_visits_setup(
+            swh_scheduler, listed_origins_by_type, limit=None
+        )
+
+        expected_origins = [origin for origin in listed_origins_by_type[visit_type]]
+
+        ret = swh_scheduler.grab_next_visits(
+            visit_type=visit_type,
+            count=len(expected_origins),
+            policy="never_visited_oldest_update_first",
+            lister_name=stored_lister.name,
+            lister_instance_name=stored_lister.instance_name,
+        )
+
+        assert len(ret) == len(expected_origins)
+        for origin in ret:
+            assert origin.lister_id == stored_lister.id
+
     def _create_task_types(self, scheduler):
         for tt in TASK_TYPES.values():
             scheduler.create_task_type(tt)
